@@ -109,9 +109,20 @@ sub print_httpd {
 }
 
  sub print_thesemodules {
+    my $opt = shift;	 
     $m = HTML::Perlinfo::Modules->new();
-    return $m->print_modules(show_only=>$_[0], full_page=>0) if $_[0] eq 'core';
-    return $m->print_modules(section=>'All Perl modules', full_page=>0);
+    if ($opt eq 'core') {
+    	return $m->print_modules(show_only=>$opt, full_page=>0);
+    }
+    elsif ($opt eq 'all') {
+    	return $m->print_modules(section=>'All Perl modules', full_page=>0);
+    }
+    elsif ($opt eq 'loaded' && ref $_[0] eq 'ARRAY') {
+    	return $m->print_modules(section=>'Loaded Files', files_in=>shift, full_page=>0);
+    }
+    else {
+	die "internal function print_thesemodules has invalid arguments: @_";
+    }	    
  }
 
 sub print_general {
